/*
 * This file is part of remco.
 * © 2016 The Remco Authors
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

package backends

import (
	"github.com/HeavyHorst/easykv/env"
	berr "github.com/HeavyHorst/remco/pkg/backends/error"
	"github.com/HeavyHorst/remco/pkg/template"
)

//EnvConfig represents the config for the env backend
type EnvConfig struct {
	template.Backend
}

// Connect creates a new envClient and fills the underlying template.Backend with the file-Backend specific data.
func (c *EnvConfig) Connect() (template.Backend, error) {
	if c == nil {
		return template.Backend{}, berr.ErrNilConfig
	}
	c.Backend.Name = "env"

	client, err := env.New()
	if err != nil {
		return c.Backend, err
	}

	c.Backend.ReadWatcher = client
	return c.Backend, nil
}

// return Backend config to allow modification before connect() for onetime param or similar
func (c *EnvConfig) GetBackend() *template.Backend {
	return &c.Backend
}
